@@ -192,6 +192,8 @@ class act_daily
         $this->objmail->Assign('http_action', HTTP_ACTION);
         $this->objmail->Assign('uri_separator', WAP_URI_SEPARATOR);
 
+        $this->news = false;
+
         $this->set_topic();
         $this->set_fdiary();
         $this->set_comment();
@@ -219,7 +221,7 @@ class act_daily
                 'tpc.id as ref_topic,'.
                 'tpc.topic as topic,'.
                 $date.' as modify,'.
-                'count(cmt.id) as ct '.
+                'tpc.post as ct '.
             'FROM '.
                 DB_PREFIX.'com_topic tpc '.
                     'LEFT JOIN '.DB_PREFIX.'com_comment cmt '.
@@ -322,7 +324,7 @@ class act_daily
                 'act.id as ref_friend,'.
                 'pro.nickname as nickname,'.
                 $date.' as modify,'.
-                'count(com.id) as ct,'.
+                'ent.post as ct,'.
                 'ent.subject as subject '.
             'FROM '.
                 DB_PREFIX.'act_account act,'.
