@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/02/04] PDOがPHP5仕様になっていたのを修正
  -      [2006/09/26] wap_config.php読み込み追加
  -      [2006/08/29] 設定ファイル名の変更に伴う修正
  -      [2006/08/20] 作成
@@ -97,7 +98,7 @@ class cal_schedule
                 'act.id';
         $stmt = $this->objdb->prepare($sql); 
         $stmt->execute(); 
-        $result = $stmt->fetchAll(PDO::FETCH_ASSOC);
+        $result = $stmt->fetchAll(PDO_FETCH_ASSOC);
 
         foreach ($result as $value){
             $this->send_schedule($value);
@@ -135,7 +136,7 @@ class cal_schedule
                 'mail_flag = '.AVAIL_ENABLE;
         $stmt = $this->objdb->prepare($sql); 
         $stmt->execute(); 
-        $result = $stmt->fetchAll(PDO::FETCH_ASSOC);
+        $result = $stmt->fetchAll(PDO_FETCH_ASSOC);
         if (empty($result)){
             return ;
         }
