@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/02/04] PDOがPHP5仕様になっていたのを修正
  -      [2006/08/29] 設定ファイル名の変更に伴う修正
  -      [2006/07/10] 作成
  - ======================================================================== */
@@ -94,7 +95,7 @@ class dia_rss
                 'visibility != '.VISIBILITY_HIDDEN.' ';
         $stmt = $this->objdb->prepare($sql); 
         $stmt->execute(); 
-        $result = $stmt->fetchAll(PDO::FETCH_ASSOC);
+        $result = $stmt->fetchAll(PDO_FETCH_ASSOC);
 
         foreach ($result as $value){
             $this->read_rss($value);
