@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/02/13] 公開フラグをビットフラグに対応
  -      [2007/02/03] 市区町村条件指定エラーの修正
  -      [2006/07/10] 作成
  - ======================================================================== */
@@ -276,11 +277,6 @@ class webapp extends WAP_friend
      */
     function get_item($ref_enquete, $form_type)
     {
-        /* 友達か？ */
-        $where = '';
-        if ($this->isFriend()){
-            $where = ' OR con.visibility = '.VISIBILITY_FRIEND;
-        }
         $sql=
             'SELECT '.
                 'con.ref_enquete as ref_enquete,'.
@@ -291,9 +287,7 @@ class webapp extends WAP_friend
                     'LEFT JOIN '.DB_PREFIX.'act_item itm '.
                     'ON itm.id = con.ref_item '.
             'WHERE '.
-                '(con.visibility = '.VISIBILITY_PUBLIC.' OR '.
-                 'con.visibility = '.VISIBILITY_PROTECTED.
-                $where.') AND '.
+                sql_query::bitFlag('con.visibility & '.$this->visibility).' AND '.
                 'con.ref_enquete = '.$ref_enquete.' AND '.
                 'con.ref_account = '.$this->ref_friend;
         $stmt = $this->objdb->prepare($sql); 
@@ -320,11 +314,6 @@ class webapp extends WAP_friend
      */
     function get_select($ref_enquete)
     {
-        /* 友達か？ */
-        $where = '';
-        if ($this->isFriend()){
-            $where = ' OR sel.visibility = '.VISIBILITY_FRIEND;
-        }
         $sql=
             'SELECT '.
                 'itm.item as item '.
@@ -334,9 +323,7 @@ class webapp extends WAP_friend
             'WHERE '.
                 'itm.id = sel.ref_item AND '.
                 'sel.ref_enquete = '.$ref_enquete.' AND '.
-                '(sel.visibility = '.VISIBILITY_PUBLIC.' OR '.
-                 'sel.visibility = '.VISIBILITY_PROTECTED.
-                $where.') AND '.
+                sql_query::bitFlag('sel.visibility & '.$this->visibility).' AND '.
                 'sel.ref_account = '.$this->ref_friend;
         $stmt = $this->objdb->prepare($sql); 
         $stmt->execute(); 
