@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/04/21] 問合せ対応状況を追加
  -      [2007/02/12] STATUS_COMMUNITYをビットフラグ
  -      [2007/02/12] VISIBILITYをビットフラグ
  -      [2007/02/02] コンテンツ記事の表示開始年を追加
@@ -338,6 +339,18 @@ define('POSITION_SPONSOR_HEAD',   1);                               // ヘッダ
 define('POSITION_SPONSOR_MIDDLE', 2);                               // 中央部位
 define('POSITION_SPONSOR_SIDE',   3);                               // 側面部位
 
+/* ---------------------------------------- */
+/* 問合せ対応状況 */
+define('STATAS_INQUIRE_NEW',        1);                             // 問合せ
+define('STATAS_INQUIRE_PENDING',    2);                             // 検討中
+define('STATAS_INQUIRE_RESPONDED',  3);                             // 対応済み
+define('STATAS_INQUIRE_TRASH',      4);                             // ゴミ箱
+
+define('STATAS_INQUIRE_LABEL_NEW',        '問合せ');
+define('STATAS_INQUIRE_LABEL_PENDING',    '検討中');
+define('STATAS_INQUIRE_LABEL_RESPONDED',  '対応済み');
+define('STATAS_INQUIRE_LABEL_TRASH',      'ゴミ箱');
+
 /* ---------------------------------------- */
 /* 日記のフォーマット */
 define('DIARY_FORMAT_PLAIN', 1);                                    // デフォルト
