@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/02/12] コミュニティメンバーステータスをビットフラグに変更
  -      [2007/01/26] ユーザーなりすまし機能追加
  -      [2006/08/29] 整形表示のエラー修正
  -      [2006/08/04] 作成
@@ -500,9 +501,7 @@ class webapp extends WAP_admin
                 DB_PREFIX.'com_names nms '.
             'WHERE '.
                 'com.id = nms.ref_community AND '.
-                '(nms.status = '.STATUS_COMMUNITY_MEMBER.' OR '.
-                 'nms.status = '.STATUS_COMMUNITY_CHANGE.' OR '.
-                 'nms.status = '.STATUS_COMMUNITY_ADMIN.')AND '.
+                sql_query::bitFlag('nms.status & '.STATUS_COMMUNITY_MEMBERS).' AND '.
                 'nms.ref_account = '.$this->id.' '.
             'ORDER BY '.
                 'nms.modify '.
@@ -561,9 +560,7 @@ class webapp extends WAP_admin
                 DB_PREFIX.'com_names '.
             'WHERE '.
                 'ref_account = '.$this->id. ' AND '.
-                '(status = '.STATUS_COMMUNITY_MEMBER.' OR '.
-                 'status = '.STATUS_COMMUNITY_CHANGE.' OR '.
-                 'status = '.STATUS_COMMUNITY_ADMIN.')';
+                sql_query::bitFlag('status & '.STATUS_COMMUNITY_MEMBERS);
         $stmt = $this->objdb->prepare($sql); 
         $stmt->execute(); 
         $result = $stmt->fetch(PDO_FETCH_ASSOC);
