@@ -293,16 +293,12 @@ class webapp extends WAP_admin
         }
         $this->objmnp->catchInput($skip);
 
-
-        /* 以下のタグを許可 */
-        $tags  = ALLOWABLE_TAGS;
-        $tags .= '<div><p><sub><sup><blockquote><hr>';
-        $tags .= '<h1><h2><h3><h4><h5><h6>';
-        $tags .= '<table><thead><tbody><tr><th><td>';
+        /* 入力条件を指定 */
         $validate_info = array(
-            'type'=> 'string',
-            'required'=> true,
-            'tags'=> $tags
+            'type'=>    'string',
+            'option'=>  null,
+            'required'=>true,
+            'effect'=>  array('RKT_validate', 'strip_slashes'),
         );
         $this->objmnp->setInput('body', $validate_info);
 
