@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/02/13] コメント投稿数をトピックに保存
  -      [2007/02/04] イベント参加処理を削除
  -      [2006/07/10] 作成
  - ======================================================================== */
@@ -322,18 +323,33 @@ class webapp extends WAP_community
      * トピックの更新日を更新
      *
      * @access private
-     * @return boolean  真偽値
+     * @return integer  データ操作結果
      */
     function update_topic()
     {
+        $sql = 
+            'SELECT '.
+                'count(*) as post '.
+            'FROM '.
+                DB_PREFIX.'com_comment '.
+            'WHERE '.
+                'ref_community = '.$this->ref_community.' AND '.
+                'ref_topic = '.$this->ref_topic;
+        $stmt = $this->objdb->prepare($sql); 
+        $stmt->execute(); 
+        $result = $stmt->fetch(PDO_FETCH_ASSOC);
+        $stmt->closeCursor();
+        $post = empty($result['post'])?0:$result['post'];
+
         $sql =
             'UPDATE '.
                 DB_PREFIX.'com_topic '.
             'SET '.
-                "modify = '".date('Y-m-d H:i:s')."' ".
+                "modify='".date('Y-m-d H:i:s')."',".
+                'post = '.$post.' '.
             'WHERE '.
-                'id ='.$this->ref_topic;
-        return $this->objdb->exec($sql);
+                'id = '.$this->ref_topic;
+        $this->objdb->exec($sql);
     }
 } // webapp
 ?>
