@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/04/21] 最新情報を別枠表示
  -      [2007/02/13] 公開レベルをビットフラグに対応
  -      [2007/02/12] コミュニティメンバーステータスをビットフラグに変更
  -      [2007/02/03] 市区町村条件指定エラーの修正
@@ -43,6 +44,12 @@ require_once WEBAPP_LIB_DIR.'wap_friend.php';
  */
 class webapp extends WAP_friend
 {
+    /**
+     * 最新情報フラグ
+     * @var integer
+     */
+    var $news = false;
+
     /**
      * 実行処理
      *
@@ -63,9 +70,13 @@ class webapp extends WAP_friend
         $this->set_friend();
         $this->set_community();
         $this->set_community_number();
+
         $this->set_diary();
         $this->set_review();
         $this->set_forum();
+        $this->Assign('news', $this->news);
+
+
         $this->set_intro();
         
         $this->doFootprint();
@@ -542,6 +553,10 @@ class webapp extends WAP_friend
         $stmt = $this->objdb->prepare($sql); 
         $stmt->execute(); 
         $result = $stmt->fetchAll(PDO_FETCH_ASSOC);
+        if (empty($result)){
+            return ;
+        }
+        $this->news = true;
 
         $this->Assign('diarys', $result);
     }
@@ -571,6 +586,10 @@ class webapp extends WAP_friend
         $stmt = $this->objdb->prepare($sql); 
         $stmt->execute(); 
         $result = $stmt->fetchAll(PDO_FETCH_ASSOC);
+        if (empty($result)){
+            return ;
+        }
+        $this->news = true;
 
         $this->Assign('reviews', $result);
     }
@@ -600,6 +619,10 @@ class webapp extends WAP_friend
         $stmt = $this->objdb->prepare($sql); 
         $stmt->execute(); 
         $result = $stmt->fetchAll(PDO_FETCH_ASSOC);
+        if (empty($result)){
+            return ;
+        }
+        $this->news = true;
 
         $this->Assign('forums', $result);
     }
