@@ -129,15 +129,16 @@ class webapp extends WAP_private
         
         $list = array();
         $row = 0;
-        $html = '<table width="100%" border="1"><tr>';
+        $html = '<table width="100%" class="border" align="center" cellpadding="4" cellspacing="0"><tr>';
         foreach ($result as $value){
             $html .= 
-                '<td><img src="'.BASE_URL.$value['src'].'" width="'.$value['width'].'" height="'.$value['height'].'"><br />'.
+                '<td style="text-align:center;"><img src="'.BASE_URL.$value['src'].'" width="'.$value['width'].'" height="'.$value['height'].'"><br />'.
                 '<a href="javascript:insertImg(\\\''.BASE_URL.$value['href'].'\\\')">'.
                 '<img src="'.BASE_URL.'resource/img/icons/picture_add.gif" width="16" height="16" alt="原寸表示" /></a>&nbsp;&nbsp;'.
                 '<a href="javascript:void(0)" onclick="insertImgLink(\\\''.BASE_URL.$value['href'].'\\\',\\\''.BASE_URL.$value['src'].'\\\')">'.
                 '<img src="'.BASE_URL.'resource/img/icons/picture_delete.gif" width="16" height="16" alt="縮小表示" /></a>&nbsp;&nbsp;'.
-                '<a href="'.HTTP_ACTION.'private/diary/upload/'.$this->ref_entry.'/'.WAP_URI_SEPARATOR.'id='.$value['id'].'&amp;delete=1" target="imgframe">'.
+                '<a href="'.HTTP_ACTION.'private/diary/upload/'.$this->ref_entry.'/'.WAP_URI_SEPARATOR.'id='.$value['id'].'&amp;delete=1" '.
+                'onclick="deleteImgs(\\\''.BASE_URL.$value['href'].'\\\',\\\''.BASE_URL.$value['src'].'\\\')" target="imgframe">'.
                 '<img src="'.BASE_URL.'resource/img/icons/cross.gif" width="16" height="16" alt="削除" /></a>'.
                 '<input type="hidden" name="ref_pictures[]" value="'.$value['id'].'" />'.
                 '</td>';
