@@ -20,6 +20,7 @@
 --      yujiro@rakuto.net
 --      http://rakuto.net/rktSNS/
 -- 更新履歴：
+--      [2007/04/21] 問合せ内容を修正、問合せ対応を追加
 --      [2007/03/11] 作成
 -- ========================================================================
 
@@ -922,10 +923,24 @@ CREATE TABLE `sns_inq_inquire` (
   `ref_category` int(11),
   `ref_account` int(11),
   `status` int(11) NOT NULL,
+  `flag` int(11) default '0',
   `name` varchar(128) NOT NULL,
   `url` varchar(128),
   `email` blob,
   `comment` text NOT NULL,
+  PRIMARY KEY  (`id`)
+) ENGINE=MyISAM AUTO_INCREMENT=1 DEFAULT CHARSET=utf8;
+
+-- 
+-- 問合せ対応
+-- 
+CREATE TABLE `sns_inq_response` (
+  `id` int(11) unsigned NOT NULL auto_increment,
+  `modify` timestamp NOT NULL,
+  `regist_date` timestamp NOT NULL,
+  `ref_inquire` int(11),
+  `ref_account` int(11) NOT NULL,
+  `send` int(11),
   `subject` varchar(255) NOT NULL,
   `body` text NOT NULL,
   PRIMARY KEY  (`id`)
